summaryrefslogtreecommitdiffstats
path: root/korganizer/eventarchiver.h
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/eventarchiver.h')
-rw-r--r--korganizer/eventarchiver.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/korganizer/eventarchiver.h b/korganizer/eventarchiver.h
index 8da86deb..f5b61e6d 100644
--- a/korganizer/eventarchiver.h
+++ b/korganizer/eventarchiver.h
@@ -50,14 +50,14 @@ class EventArchiver : public TQObject
TQ_OBJECT
public:
- EventArchiver( TQObject* tqparent = 0, const char* name = 0 );
+ EventArchiver( TQObject* parent = 0, const char* name = 0 );
virtual ~EventArchiver();
/**
* Delete or archive events once
* @param calendar the calendar to archive
* @param limitDate all events *before* the limitDate (not included) will be deleted/archived.
* @param widget tqparent widget for message boxes
* Confirmation and "no events to process" dialogs will be shown
*/
void runOnce( Calendar* calendar, const TQDate& limitDate, TQWidget* widget );
@@ -65,7 +65,7 @@ class EventArchiver : public TQObject
/**
* Delete or archive events. This is called regularly, when auto-archiving is enabled
* @param calendar the calendar to archive
* @param widget tqparent widget for message boxes
* @param withGUI whether this is called from the dialog, so message boxes should be shown.
* Note that error dialogs like "cannot save" are shown even if from this method, so widget
* should be set in all cases.
@@ -50,14 +50,14 @@ class EventArchiver : public TQObject
* @param calendar the calendar to archive
* @param limitDate all events *before* the limitDate (not included) will be deleted/archived.
- * @param widget tqparent widget for message boxes
+ * @param widget parent widget for message boxes
* Confirmation and "no events to process" dialogs will be shown
*/
@@ -65,7 +65,7 @@ class EventArchiver : public TQObject
* Delete or archive events. This is called regularly, when auto-archiving is enabled
* @param calendar the calendar to archive
- * @param widget tqparent widget for message boxes
+ * @param widget parent widget for message boxes
* @param withGUI whether this is called from the dialog, so message boxes should be shown.
* Note that error dialogs like "cannot save" are shown even if from this method, so widget